@@ -9,7 +9,7 @@ from pydwf.core.api.sub_api import DwfDevice_SubAPI
 
 
 class AnalogImpedance(DwfDevice_SubAPI):
-    """The |AnalogImpedance| class provides access to the Analog Impedance measurement functionality of a
+    """The |AnalogImpedance| class provides access to the analog impedance measurement functionality of a
     |DwfDevice:link|.
 
     Attention:
@@ -22,7 +22,7 @@ class AnalogImpedance(DwfDevice_SubAPI):
     # pylint: disable=too-many-public-methods
 
     def reset(self) -> None:
-        """Reset the Analog Impedance measurement functionality.
+        """Reset the analog impedance measurement functionality.
 
         Raises:
             DwfLibraryError: There was an error while executing the reset operation.
@@ -32,7 +32,7 @@ class AnalogImpedance(DwfDevice_SubAPI):
             raise self.dwf.exception()
 
     def configure(self, start: bool) -> None:
-        """Configure the AnalogImpedance measurement, and optionally start a measurement.
+        """Configure the analog impedance measurement, and optionally start a measurement.
 
         Parameters:
             start (bool): Whether to start the measurement.
@@ -45,7 +45,7 @@ class AnalogImpedance(DwfDevice_SubAPI):
             raise self.dwf.exception()
 
     def status(self) -> DwfState:
-        """Return the status of the AnalogImpedance measurement.
+        """Return the status of the analog impedance measurement.
 
         Returns:
             DwfState: The status of the measurement.
