@@ -18,13 +18,24 @@ class DigitalI2c(DwfDevice_SubAPI):
     """
 
     def reset(self) -> None:
-        """Reset the I²C protocol instrument."""
+        """Reset the I²C protocol instrument.
+
+        Raises:
+            DwfLibraryError: There was an error while executing the reset operation.
+        """
         result = self.lib.FDwfDigitalI2cReset(self.hdwf)
         if result != RESULT_SUCCESS:
             raise self.dwf.exception()
 
     def clear(self) -> int:
-        """Clear the I²C bus."""
+        """Clear the I²C bus.
+
+        Returns:
+            int: "bus free" indicator.
+
+        Raises:
+            DwfLibraryError: There was an error while executing the operation.
+        """
         c_bus_free = typespec_ctypes.c_int()
         result = self.lib.FDwfDigitalI2cClear(self.hdwf, c_bus_free)
         if result != RESULT_SUCCESS:
@@ -33,37 +44,86 @@ class DigitalI2c(DwfDevice_SubAPI):
         return bus_free
 
     def stretchSet(self, stretch_enable: int) -> None:
-        """Set stretch behavior."""
-        result = self.lib.FDwfDigitalI2cStretchSet(self.hdwf, stretch_enable)
+        """Set I²C stretch behavior.
+
+        Parameters:
+            stretch_enable (bool): True to enable stretch, False to disable.
+
+        Raises:
+            DwfLibraryError: There was an error while executing the operation.
+        """
+        result = self.lib.FDwfDigitalI2cStretchSet(self.hdwf, bool(stretch_enable))
         if result != RESULT_SUCCESS:
             raise self.dwf.exception()
 
-    def rateSet(self, rate: float) -> None:
-        """Set rate."""
-        result = self.lib.FDwfDigitalI2cRateSet(self.hdwf, rate)
+    def rateSet(self, data_rate: float) -> None:
+        """Set  I²C data rate, in Hz.
+
+        Parameters:
+            data_rate (float):  I²C data rate. Often-encountered rates are 100 kHz and 400 kHz, but many
+                modern I²C devices support higher data rates. Check the datasheet.
+
+        Raises:
+            DwfLibraryError: There was an error while executing the operation.
+        """
+        result = self.lib.FDwfDigitalI2cRateSet(self.hdwf, data_rate)
         if result != RESULT_SUCCESS:
             raise self.dwf.exception()
 
     def readNakSet(self, nak_last_read_byte: int) -> None:
-        """Set read NAK state."""
+        """Set read NAK state.
+
+        Parameters:
+            nak_last_read_byte (int): (undocumented)
+
+        Raises:
+            DwfLibraryError: There was an error while executing the operation.
+        """
         result = self.lib.FDwfDigitalI2cReadNakSet(self.hdwf, nak_last_read_byte)
         if result != RESULT_SUCCESS:
             raise self.dwf.exception()
 
     def sclSet(self, channel_index: int) -> None:
-        """Set SCL."""
+        """Set the channel where the clock (SCL) signal is transmitted.
+
+        Parameters:
+            channel_index (int): The channel (digital pin number) on which to generate the SCL clock.
+
+        Raises:
+            DwfLibraryError: There was an error while executing the operation.
+        """
         result = self.lib.FDwfDigitalI2cSclSet(self.hdwf, channel_index)
         if result != RESULT_SUCCESS:
             raise self.dwf.exception()
 
     def sdaSet(self, channel_index: int) -> None:
-        """Set SDA."""
+        """Set the channel where the data (SDA) signal is transmitted/received.
+
+        Parameters:
+            channel_index (int): The channel (digital pin number) on which to send/receive SDA data.
+
+        Raises:
+            DwfLibraryError: There was an error while executing the operation.
+        """
         result = self.lib.FDwfDigitalI2cSdaSet(self.hdwf, channel_index)
         if result != RESULT_SUCCESS:
             raise self.dwf.exception()
 
     def writeRead(self, address: int, tx: List[int], number_of_rx_bytes: int) -> Tuple[int, List[int]]:
-        """Perform I²C combined write, read."""
+        """Perform an I²C combined write/read operation.
+
+        Parameters:
+            address (int): Address of the target device.
+            tx (List[int]): Words to send.
+            number_of_rx_bytes (int): Number of octets to receive.
+
+        Returns:
+            Tuple[int, List[int]:
+                The first element is the NAK indication; the second element is a list of values received.
+
+        Raises:
+            DwfLibraryError: There was an error while executing the operation.
+        """
         c_nak = typespec_ctypes.c_int()
 
         tx_list = list(tx)
@@ -94,7 +154,19 @@ class DigitalI2c(DwfDevice_SubAPI):
         return (nak, rx_list)
 
     def read(self, address: int, number_of_words: int) -> Tuple[int, List[int]]:
-        """Perform I²C read."""
+        """Perform an I²C read operation.
+
+        Parameters:
+            address (int): Address of the target device.
+            number_of_words (int): Number of octets to receive.
+
+        Returns:
+            Tuple[int, List[int]:
+                The first element is the NAK indication; the second element is a list of values received.
+
+        Raises:
+            DwfLibraryError: There was an error while executing the operation.
+        """
 
         c_nak = typespec_ctypes.c_int()
 
@@ -113,7 +185,18 @@ class DigitalI2c(DwfDevice_SubAPI):
         return (nak, rx_list)
 
     def write(self, address: int, tx: List[int]) -> int:
-        """Perform I²C write."""
+        """Perform an I²C write operation.
+
+        Parameters:
+            address (int): Address of the target device.
+            tx (List[int]): Words to send.
+
+        Returns:
+            int: NAK indication.
+
+        Raises:
+            DwfLibraryError: There was an error while executing the operation.
+        """
 
         c_nak = typespec_ctypes.c_int()
 
@@ -134,7 +217,18 @@ class DigitalI2c(DwfDevice_SubAPI):
         return nak
 
     def writeOne(self, address: int, tx: int) -> int:
-        """Perform I²C write of a single octet."""
+        """Perform an I²C write operation of a single octet.
+
+        Parameters:
+            address (int): Address of the target device.
+            tx (int): Word to send.
+
+        Returns:
+            int: NAK indication.
+
+        Raises:
+            DwfLibraryError: There was an error while executing the operation.
+        """
         c_nak = typespec_ctypes.c_int()
 
         result = self.lib.FDwfDigitalI2cWriteOne(self.hdwf, address, tx, c_nak)
