@@ -324,9 +324,9 @@ class DigitalIn(DwfDevice_SubAPI):
         result = self.lib.FDwfDigitalInAcquisitionModeInfo(self.hdwf, c_acquisition_mode_bitset)
         if result != RESULT_SUCCESS:
             raise self.dwf.exception()
-        acquisiton_mode_bitset = c_acquisition_mode_bitset.value
+        acquisition_mode_bitset = c_acquisition_mode_bitset.value
         acquisition_mode_list = [acquisition_mode for acquisition_mode in DwfAcquisitionMode
-                                 if acquisiton_mode_bitset & (1 << acquisition_mode.value)]
+                                 if acquisition_mode_bitset & (1 << acquisition_mode.value)]
         return acquisition_mode_list
 
     def acquisitionModeSet(self, acquisition_mode: DwfAcquisitionMode) -> None:
@@ -513,9 +513,9 @@ class DigitalIn(DwfDevice_SubAPI):
         if result != RESULT_SUCCESS:
             raise self.dwf.exception()
 
-    def triggerLengthSet(self, secMin: float, secMax: float, idxSync: int) -> None:
+    def triggerLengthSet(self, trigger_length_min: float, trigger_length_max: float, idxSync: int) -> None:
         """Set trigger length."""
-        result = self.lib.FDwfDigitalInTriggerLengthSet(self.hdwf, secMin, secMax, idxSync)
+        result = self.lib.FDwfDigitalInTriggerLengthSet(self.hdwf, trigger_length_min, trigger_length_max, idxSync)
         if result != RESULT_SUCCESS:
             raise self.dwf.exception()
 
