@@ -20,9 +20,10 @@ class DigitalIO(DwfDevice_SubAPI):
     """
 
     def reset(self) -> None:
-        """Reset all DigitalIO parameters to default values.
+        """Reset all |DigitalIO| settings to default values.
 
-        It sets the output enables to zero (tri-state), output value to zero, and configures the DigitalIO.
+        It sets the outputs to tri-state (high impedance, not enabled), output value to zero,
+        and configures the |DigitalIO|.
 
         If auto-configure is enabled, the values are immediately effectuated.
 
@@ -34,9 +35,9 @@ class DigitalIO(DwfDevice_SubAPI):
             raise self.dwf.exception()
 
     def configure(self) -> None:
-        """Configure the DigitalIO functionality.
+        """Configure the |DigitalIO| functionality.
 
-        This does not have to be used if AutoConfiguration is enabled.
+        This method does not have to be used if auto-configuration is enabled.
 
         Raises:
             DwfLibraryError: There was an error while executing the configure operation.
@@ -48,8 +49,8 @@ class DigitalIO(DwfDevice_SubAPI):
     def status(self) -> None:
         """Read the |DigitalIO| status and input values from the device to the PC.
 
-        Note that this method does not return a value, since the |DigitalIO| functionality is not driven
-        by a state machine.
+        Note that the |DigitalIO| functionality is not managed by a state machine,
+        so this method does not return a value.
 
         Raises:
             DwfLibraryError: There was an error while executing the status operation.
@@ -64,11 +65,14 @@ class DigitalIO(DwfDevice_SubAPI):
         The *output enable state* of a pin determines if it is driven as an output.
         If not, it is in high impedance (also known as high Z) mode.
 
+        Only digital pins that are used as outputs should be enabled; digital pins that are used as inputs
+        should remain disabled (the default state after reset).
+
         This is the 32-bits version of this method. For the 64-bits version, see :py:meth:`outputEnableInfo64`.
         The 32 and 64 bits refer here to the maximum number of digital pins that the methods can handle.
 
         Returns:
-            int: a bitmask of pins that can be used as outputs.
+            int: A bitmask of pins that can be used as outputs.
 
         Raises:
             DwfLibraryError: There was an error while executing the operation.
@@ -86,11 +90,14 @@ class DigitalIO(DwfDevice_SubAPI):
         The *output enable* state of a pin determines if it is driven as an output.
         If not, it is in high impedance (also known as high Z) mode.
 
+        Only digital pins that are used as outputs should be enabled; digital pins that are used as inputs
+        should remain disabled (the default state after reset).
+
         This is the 32-bits version of this method. For the 64-bits version, see :py:meth:`outputEnableSet64`.
         The 32 and 64 bits refer here to the maximum number of digital pins that the methods can handle.
 
         Parameters:
-            output_enable (int): a bitmask of pins that will be used as outputs.
+            output_enable (int): A bitmask of pins that will be used as outputs.
 
         Raises:
             DwfLibraryError: There was an error while executing the operation.
@@ -105,11 +112,14 @@ class DigitalIO(DwfDevice_SubAPI):
         The *output enable* state of a pin determines if it is driven as an output.
         If not, it is in high impedance (also known as high Z) mode.
 
+        Only digital pins that are used as outputs should be enabled; digital pins that are used as inputs
+        should remain disabled (the default state after reset).
+
         This is the 32-bits version of this method. For the 64-bits version, see :py:meth:`outputEnableGet64`.
         The 32 and 64 bits refer here to the maximum number of digital pins that the methods can handle.
 
         Returns:
-            int: a bitmask of pins that are currently configured as outputs.
+            int: A bitmask of pins that are currently configured as outputs.
 
         Raises:
             DwfLibraryError: There was an error while executing the operation.
@@ -128,7 +138,7 @@ class DigitalIO(DwfDevice_SubAPI):
         The 32 and 64 bits refer here to the maximum number of digital pins that the methods can handle.
 
         Returns:
-            int: a bitmask of pins that can be used as outputs.
+            int: A bitmask of pins that can be used as outputs.
 
         Raises:
             DwfLibraryError: There was an error while executing the operation.
@@ -147,7 +157,7 @@ class DigitalIO(DwfDevice_SubAPI):
         The 32 and 64 bits refer here to the maximum number of digital pins that the methods can handle.
 
         Parameters:
-            output (int): a bitmask of pins that will be driven high.
+            output (int): A bitmask of pins that will be driven high.
 
         Raises:
             DwfLibraryError: There was an error while executing the operation.
@@ -163,7 +173,7 @@ class DigitalIO(DwfDevice_SubAPI):
         The 32 and 64 bits refer here to the maximum number of digital pins that the methods can handle.
 
         Returns:
-            int: a bitmask of pins that are currently set to high.
+            int: A bitmask of pins that are currently set to high.
 
         Raises:
             DwfLibraryError: There was an error while executing the operation.
@@ -182,7 +192,7 @@ class DigitalIO(DwfDevice_SubAPI):
         The 32 and 64 bits refer here to the maximum number of digital pins that the methods can handle.
 
         Returns:
-            int: a bitmask of pins that can be used as inputs.
+            int: A bitmask of pins that can be used as inputs.
 
         Raises:
             DwfLibraryError: There was an error while executing the operation.
@@ -204,7 +214,7 @@ class DigitalIO(DwfDevice_SubAPI):
         The 32 and 64 bits refer here to the maximum number of digital pins that the methods can handle.
 
         Returns:
-            int: a bitmask of pins that are currently read as High.
+            int: A bitmask of pins that are currently read as high.
 
         Raises:
             DwfLibraryError: There was an error while executing the operation.
@@ -222,11 +232,14 @@ class DigitalIO(DwfDevice_SubAPI):
         The *output enable state* of a pin determines if it is driven as an output.
         If not, it is in high impedance (also known as high Z) mode.
 
+        Only digital pins that are used as outputs should be enabled; digital pins that are used as inputs
+        should remain disabled (the default state after reset).
+
         This is the 64-bits version of this method. For the 32-bits version, see :py:meth:`outputEnableInfo`.
         The 32 and 64 bits refer here to the maximum number of digital pins that the methods can handle.
 
         Returns:
-            int: a bitmask of pins that can be used as outputs.
+            int: A bitmask of pins that can be used as outputs.
 
         Raises:
             DwfLibraryError: There was an error while executing the operation.
@@ -244,11 +257,14 @@ class DigitalIO(DwfDevice_SubAPI):
         The *output enable* state of a pin determines if it is driven as an output.
         If not, it is in high impedance (also known as high Z) mode.
 
+        Only digital pins that are used as outputs should be enabled; digital pins that are used as inputs
+        should remain disabled (the default state after reset).
+
         This is the 64-bits version of this method. For the 32-bits version, see :py:meth:`outputEnableSet`.
         The 32 and 64 bits refer here to the maximum number of digital pins that the methods can handle.
 
         Parameters:
-            output_enable (int): a bitmask of pins that will be used as outputs.
+            output_enable (int): A bitmask of pins that will be used as outputs.
 
         Raises:
             DwfLibraryError: There was an error while executing the operation.
@@ -263,11 +279,14 @@ class DigitalIO(DwfDevice_SubAPI):
         The *output enable* state of a pin determines if it is driven as an output.
         If not, it is in high impedance (also known as high Z) mode.
 
+        Only digital pins that are used as outputs should be enabled; digital pins that are used as inputs
+        should remain disabled (the default state after reset).
+
         This is the 64-bits version of this method. For the 32-bits version, see :py:meth:`outputEnableGet`.
         The 32 and 64 bits refer here to the maximum number of digital pins that the methods can handle.
 
         Returns:
-            int: a bitmask of pins that are currently configured as outputs.
+            int: A bitmask of pins that are currently configured as outputs.
 
         Raises:
             DwfLibraryError: There was an error while executing the operation.
@@ -286,7 +305,7 @@ class DigitalIO(DwfDevice_SubAPI):
         The 32 and 64 bits refer here to the maximum number of digital pins that the methods can handle.
 
         Returns:
-            int: a bitmask of pins that can be used as outputs.
+            int: A bitmask of pins that can be used as outputs.
 
         Raises:
             DwfLibraryError: There was an error while executing the operation.
@@ -305,7 +324,7 @@ class DigitalIO(DwfDevice_SubAPI):
         The 32 and 64 bits refer here to the maximum number of digital pins that the methods can handle.
 
         Parameters:
-            output (int): a bitmask of pins that will be driven high.
+            output (int): A bitmask of pins that will be driven high.
 
         Raises:
             DwfLibraryError: There was an error while executing the operation.
@@ -321,7 +340,7 @@ class DigitalIO(DwfDevice_SubAPI):
         The 32 and 64 bits refer here to the maximum number of digital pins that the methods can handle.
 
         Returns:
-            int: a bitmask of pins that are currently set to high.
+            int: A bitmask of pins that are currently set to high.
 
         Raises:
             DwfLibraryError: There was an error while executing the operation.
@@ -340,7 +359,7 @@ class DigitalIO(DwfDevice_SubAPI):
         The 32 and 64 bits refer here to the maximum number of digital pins that the methods can handle.
 
         Returns:
-            int: a bitmask of pins that can be used as inputs.
+            int: A bitmask of pins that can be used as inputs.
 
         Raises:
             DwfLibraryError: There was an error while executing the operation.
@@ -362,7 +381,7 @@ class DigitalIO(DwfDevice_SubAPI):
         The 32 and 64 bits refer here to the maximum number of digital pins that the methods can handle.
 
         Returns:
-            int: a bitmask of pins that are currently read as High.
+            int: A bitmask of pins that are currently read as high.
 
         Raises:
             DwfLibraryError: There was an error while executing the operation.
