@@ -261,7 +261,7 @@ class DigitalOut(DwfDevice_SubAPI):
         """Get the slope for the digital-out trigger.
 
         Returns:
-            DwfTriggerSlote: The currently configured trigger slope.
+            DwfTriggerSlope: The currently configured trigger slope.
         """
         c_trigger_slope = typespec_ctypes.DwfTriggerSlope()
         result = self.lib.FDwfDigitalOutTriggerSlopeGet(self.hdwf, c_trigger_slope)
@@ -507,12 +507,12 @@ class DigitalOut(DwfDevice_SubAPI):
         Returns:
             int: The number of custom data bits that can be specified for the channel.
         """
-        c_max_databits = typespec_ctypes.c_unsigned_int()
-        result = self.lib.FDwfDigitalOutDataInfo(self.hdwf, channel_index, c_max_databits)
+        c_max_data_bits = typespec_ctypes.c_unsigned_int()
+        result = self.lib.FDwfDigitalOutDataInfo(self.hdwf, channel_index, c_max_data_bits)
         if result != RESULT_SUCCESS:
             raise self.dwf.exception()
-        max_databits = c_max_databits.value
-        return max_databits
+        max_data_bits = c_max_data_bits.value
+        return max_data_bits
 
     def dataSet(self, channel_index: int, bits: str, tristate: bool = False) -> None:
         """Set digital-out arbitrary channel data."""
