@@ -56,11 +56,12 @@ class DigitalSpi(DwfDevice_SubAPI):
             raise self.dwf.exception()
 
     def dataSet(self, spi_data_bit: int, channel_index: int) -> None:
-        """Bind SPI data bit to physical channel pin.
+        """Bind SPI data bit to a physical channel pin.
 
         Parameters:
             spi_data_bit (int):
-                SPI data bit:
+
+                The data bit to configure:
 
                 * 0: DQ0 / MOSI
                 * 1: DQ1 / MISO
@@ -82,7 +83,8 @@ class DigitalSpi(DwfDevice_SubAPI):
 
         Parameters:
             spi_data_bit (int):
-                SPI data bit:
+
+                The data bit to configure:
 
                 * 0: DQ0 / MOSI
                 * 1: DQ1 / MISO
@@ -106,11 +108,15 @@ class DigitalSpi(DwfDevice_SubAPI):
         Parameters:
             spi_mode (int):
 
+                The values for CPOL (polarity) and CPHA (phase) to use with the device under test:
+
                 * 0: CPOL = 0, CPHA = 0
                 * 1: CPOL = 0, CPHA = 1
                 * 2: CPOL = 1, CPHA = 0
                 * 3: CPOL = 1, CPHA = 1
 
+                Refer to the slave device's datasheet to select the correct value.
+
         Raises:
             DwfLibraryError: There was an error while executing the operation.
         """
@@ -124,6 +130,8 @@ class DigitalSpi(DwfDevice_SubAPI):
         Parameters:
             bit_order (int):
 
+                Select the bit order of each word sent out:
+
                 * 1: MSB first, LSB last
                 * 0: LSB first, MSB last
 
@@ -138,13 +146,25 @@ class DigitalSpi(DwfDevice_SubAPI):
         """Set the chip select (CS) status.
 
         Parameters:
+
             channel_index (int):
                 Digital channel (pin) for this data bit.
+
             level (int):
+
+                The Chip Select level to configure.
+
                 *  0: low
                 *  1: high
                 * -1: Z (high impedance)
 
+                The CS (chip select) is usually an active-low signal, from the
+                SPI bus master to a specific SPI device. before starting a bus
+                request, the master should set CS to 0 for the chip it wants to talk to.
+
+                Each slave on an SPI bus has its own CS line. Generally, either zero or
+                one of them should be low at any time.
+
         Raises:
             DwfLibraryError: There was an error while executing the operation.
         """
@@ -170,7 +190,7 @@ class DigitalSpi(DwfDevice_SubAPI):
             List[int]: The data-words received.
 
         Raises:
-            DwfLibraryError: There was an error while executing the operation.
+            DwfLibraryError: There was an error while executing the write/read operation.
         """
         tx_list = list(tx)
 
@@ -197,7 +217,7 @@ class DigitalSpi(DwfDevice_SubAPI):
         return rx_list
 
     def writeRead16(self, transfer_type: int, bits_per_word: int, tx: List[int]) -> List[int]:
-        """Write and read multiple SPI data-words, with up to 16 bits per word.
+        """Write and read multiple SPI data-words, with up to 16 bits per data-word.
 
         Parameters:
             transfer_type (int):
@@ -214,7 +234,7 @@ class DigitalSpi(DwfDevice_SubAPI):
             List[int]: The data-words received.
 
         Raises:
-            DwfLibraryError: There was an error while executing the operation.
+            DwfLibraryError: There was an error while executing the write/read operation.
         """
         tx_list = list(tx)
 
@@ -241,7 +261,7 @@ class DigitalSpi(DwfDevice_SubAPI):
         return rx_list
 
     def writeRead32(self, transfer_type: int, bits_per_word: int, tx: List[int]) -> List[int]:
-        """Write and read multiple SPI data-words, with up to 32 bits per word.
+        """Write and read multiple SPI data-words, with up to 32 bits per data-word.
 
         Parameters:
             transfer_type (int):
@@ -258,7 +278,7 @@ class DigitalSpi(DwfDevice_SubAPI):
             List[int]: The data-words received.
 
         Raises:
-            DwfLibraryError: There was an error while executing the operation.
+            DwfLibraryError: There was an error while executing the write/read operation.
         """
 
         tx_list = list(tx)
@@ -286,7 +306,7 @@ class DigitalSpi(DwfDevice_SubAPI):
         return rx_list
 
     def read(self, transfer_type: int, bits_per_word: int, number_of_words: int) -> List[int]:
-        """Read multiple SPI data-words, with up to 8 bits per word.
+        """Read multiple SPI data-words, with up to 8 bits per data-word.
 
         Parameters:
             transfer_type (int):
@@ -303,7 +323,7 @@ class DigitalSpi(DwfDevice_SubAPI):
             List[int]: The data-words received.
 
         Raises:
-            DwfLibraryError: There was an error while executing the operation.
+            DwfLibraryError: There was an error while executing the read operation.
         """
 
         buffer_type = typespec_ctypes.c_unsigned_char * number_of_words
@@ -323,33 +343,8 @@ class DigitalSpi(DwfDevice_SubAPI):
 
         return rx_list
 
-    def readOne(self, transfer_type: int, bits_per_word: int) -> int:
-        """Read a single SPI data-word, with up to 32 bits.
-
-        Parameters:
-            transfer_type (int):
-                * 0: SISO
-                * 1: MOSI/MISO
-                * 2: dual
-                * 4: quad
-            bits_per_word (int):
-                The number of bits of the data-word (1..32).
-
-        Returns:
-            int: The data-word received.
-
-        Raises:
-            DwfLibraryError: There was an error while executing the operation.
-        """
-        c_rx = typespec_ctypes.c_unsigned_int()
-        result = self.lib.FDwfDigitalSpiReadOne(self.hdwf, transfer_type, bits_per_word, c_rx)
-        if result != RESULT_SUCCESS:
-            raise self.dwf.exception()
-        rx = c_rx.value
-        return rx
-
     def read16(self, transfer_type: int, bits_per_word: int, number_of_words: int) -> List[int]:
-        """Read multiple SPI data-words, with up to 16 bits per word.
+        """Read multiple SPI data-words, with up to 16 bits per data-word.
 
         Parameters:
             transfer_type (int):
@@ -366,7 +361,7 @@ class DigitalSpi(DwfDevice_SubAPI):
             List[int]: The data-words received.
 
         Raises:
-            DwfLibraryError: There was an error while executing the operation.
+            DwfLibraryError: There was an error while executing the read operation.
         """
 
         buffer_type = typespec_ctypes.c_unsigned_short * number_of_words
@@ -387,7 +382,7 @@ class DigitalSpi(DwfDevice_SubAPI):
         return rx_list
 
     def read32(self, transfer_type: int, bits_per_word: int, number_of_words: int) -> List[int]:
-        """Read multiple SPI data-words, with up to 32 bits per word.
+        """Read multiple SPI data-words, with up to 32 bits per data-word.
 
         Parameters:
             transfer_type (int):
@@ -404,7 +399,7 @@ class DigitalSpi(DwfDevice_SubAPI):
             List[int]: The data-words received.
 
         Raises:
-            DwfLibraryError: There was an error while executing the operation.
+            DwfLibraryError: There was an error while executing the read operation.
         """
 
         buffer_type = typespec_ctypes.c_unsigned_int * number_of_words
@@ -424,6 +419,32 @@ class DigitalSpi(DwfDevice_SubAPI):
 
         return rx_list
 
+    def readOne(self, transfer_type: int, bits_per_word: int) -> int:
+        """Read a single SPI data-word, with up to 32 bits.
+
+        Parameters:
+            transfer_type (int):
+
+                * 0: SISO
+                * 1: MOSI/MISO
+                * 2: dual
+                * 4: quad
+            bits_per_word (int):
+                The number of bits of the data-word (1..32).
+
+        Returns:
+            int: The data-word received.
+
+        Raises:
+            DwfLibraryError: There was an error while executing the read operation.
+        """
+        c_rx = typespec_ctypes.c_unsigned_int()
+        result = self.lib.FDwfDigitalSpiReadOne(self.hdwf, transfer_type, bits_per_word, c_rx)
+        if result != RESULT_SUCCESS:
+            raise self.dwf.exception()
+        rx = c_rx.value
+        return rx
+
     def write(self, transfer_type: int, bits_per_word: int, tx: List[int]) -> None:
         """Write multiple SPI data-words, with up to 32 bits per data-word.
 
@@ -439,7 +460,7 @@ class DigitalSpi(DwfDevice_SubAPI):
                 The data-words to write.
 
         Raises:
-            DwfLibraryError: There was an error while executing the operation.
+            DwfLibraryError: There was an error while executing the write operation.
         """
         tx_list = list(tx)
 
@@ -458,27 +479,6 @@ class DigitalSpi(DwfDevice_SubAPI):
         if result != RESULT_SUCCESS:
             raise self.dwf.exception()
 
-    def writeOne(self, transfer_type: int, bits_per_word: int, tx: int) -> None:
-        """Write a single SPI data-word, with up to 32 bits per data-word.
-
-        Parameters:
-            transfer_type (int):
-                * 0: SISO
-                * 1: MOSI/MISO
-                * 2: dual
-                * 4: quad
-            bits_per_word (int):
-                The number of bits of the data-word (1..32).
-            tx (int):
-                The data-word to write.
-
-        Raises:
-            DwfLibraryError: There was an error while executing the operation.
-        """
-        result = self.lib.FDwfDigitalSpiWriteOne(self.hdwf, transfer_type, bits_per_word, tx)
-        if result != RESULT_SUCCESS:
-            raise self.dwf.exception()
-
     def write16(self, transfer_type: int, bits_per_word: int, tx: List[int]) -> None:
         """Write multiple SPI data-words, with up to 16 bits per data-word.
 
@@ -494,7 +494,7 @@ class DigitalSpi(DwfDevice_SubAPI):
                 The data-words to write.
 
         Raises:
-            DwfLibraryError: There was an error while executing the operation.
+            DwfLibraryError: There was an error while executing the write operation.
         """
         tx_list = list(tx)
 
@@ -528,7 +528,7 @@ class DigitalSpi(DwfDevice_SubAPI):
                 The data-words to write.
 
         Raises:
-            DwfLibraryError: There was an error while executing the operation.
+            DwfLibraryError: There was an error while executing the write operation.
         """
         tx_list = list(tx)
 
@@ -545,3 +545,24 @@ class DigitalSpi(DwfDevice_SubAPI):
             tx_buffer, number_of_words)
         if result != RESULT_SUCCESS:
             raise self.dwf.exception()
+
+    def writeOne(self, transfer_type: int, bits_per_word: int, tx: int) -> None:
+        """Write a single SPI data-word, with up to 32 bits.
+
+        Parameters:
+            transfer_type (int):
+                * 0: SISO
+                * 1: MOSI/MISO
+                * 2: dual
+                * 4: quad
+            bits_per_word (int):
+                The number of bits of the data-word (1..32).
+            tx (int):
+                The data-word to write.
+
+        Raises:
+            DwfLibraryError: There was an error while executing the write operation.
+        """
+        result = self.lib.FDwfDigitalSpiWriteOne(self.hdwf, transfer_type, bits_per_word, tx)
+        if result != RESULT_SUCCESS:
+            raise self.dwf.exception()
