@@ -1,6 +1,6 @@
 """Implementation of the |pydwf.utilities.open_dwf_device| function."""
 
-from typing import Optional, Callable
+from typing import Optional, Callable, Dict, Any
 
 from pydwf.core.dwf_library import DwfLibrary
 from pydwf.core.dwf_device import DwfDevice
@@ -9,7 +9,7 @@ from pydwf.core.auxiliary.exceptions import PyDwfError
 
 
 def open_dwf_device(dwf: DwfLibrary, serial_number: Optional[str] = None,
-                    configuration_fitness_func: Optional[Callable] = None,
+                    configuration_fitness_func: Optional[Callable[[Dict[str, Any]], Optional[int]]] = None,
                     enum_filter: Optional[DwfEnumFilter] = None) -> DwfDevice:
     """Open a device identified by its serial number, optionally selecting a preferred configuration.
 
@@ -22,6 +22,24 @@ def open_dwf_device(dwf: DwfLibrary, serial_number: Optional[str] = None,
             Digilent Waveforms device serial numbers consist of 12 hexadecimal digits.
         configuration_fitness_func (Callable):
             A function to select the preferred configuration of the selected device.
+
+            This function is called for each of the available cunfigurations of the selected device.
+
+            This function takes a single parameter *configuration_info*, which is a dictionary
+            with string keys that correspond to the names of each of the |DwfEnumConfigInfo:link| values.
+
+            The function should return *None* if the configuration is unsuitable, or otherwise
+            an integer score that reflects the 'desirability' of that particular configuration for
+            the task at hand.
+
+            This sounds complicated, but in practice this function is very easy to define for
+            most common use-cases. For example, to select a configuration that maximizes the
+            analog input buffer size, use this:
+
+            .. code-block:: python
+
+               fitness_func = lambda config_parameters: config_parameters["AnalogInBufferSize"]
+
         enum_filter (Optional[DwfEnumFilter]):
             An optional filter to limit the device enumeration to certain device types.
             In None, enumerate all devices.
@@ -30,7 +48,7 @@ def open_dwf_device(dwf: DwfLibrary, serial_number: Optional[str] = None,
         DwfDevice: The |DwfDevice:link| created as a result of this call.
 
     Raises:
-        PyDwfError: could not select a unique candidate device.
+        PyDwfError: could not select a unique candidate device, or no usable configuration detected.
     """
 
     if enum_filter is None:
@@ -95,8 +113,14 @@ def open_dwf_device(dwf: DwfLibrary, serial_number: Optional[str] = None,
 
         configuration_fitness = configuration_fitness_func(configuration_info)
 
+        if configuration_fitness is None:
+            continue
+
         if best_configuration_index is None or configuration_fitness > best_configuration_fitness:
             best_configuration_index = configuration_index
             best_configuration_fitness = configuration_fitness
 
+    if best_configuration_index is None:
+        raise PyDwfError("No acceptable configuration was found.")
+
     return dwf.deviceControl.open(device_index, best_configuration_index)
